--[[---------------------------------------------------------------------------

Copyright (c) 2008-2017 by K. Scott Piel 
All Rights Reserved

E-mail: < kscottpiel@gmail.com >

This file is part of nUI.

The author no longer develops or directly supports this addon and has released it
into the public domain under the Creative Commons Attribution-NonCommercial 3.0 
Unported license - a copy of which is included in this distribution. This source
may not be distributed without said license.
	   
nUI is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; 
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the enclosed license for more details.
	
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS  "AS IS" AND 
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT  LIMITED TO, THE IMPLIED 
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, 
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF 
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED 
OF THE POSSIBILITY OF SUCH DAMAGE.

--]]---------------------------------------------------------------------------

local addonName, addon = ...

local conRO = nil;

-------------------------------------------------------------------------------------
-- ConRO (Conflict Rotation Optimizer )

local function DetectConRO()

    local function FetchKeybind(self, spellID, i)
        if self.Keybinds[spellID] == nil then
            self.Keybinds[spellID] = {};
        end

        tinsert(self.Keybinds[spellID], 'nUI_ActionBar_Button' .. i);
    end

    local function FetchSpells(self, button, i, keyBind)
        local slot = ActionButton_GetPagedID(button) or ActionButton_CalculateAction(button) or button:GetAttribute('action') or 0;
        if HasAction(slot) then
            local spellID, _;
            local actionType, id = GetActionInfo(slot);
            if actionType == 'macro' then id = GetMacroSpell(id) end
            if actionType == 'item' then
                spellID = GetItemInfo(id);
            elseif actionType == 'spell' or (actionType == 'macro' and id) then
                spellID = id;
            end
            if spellID then
                if self.Spells[spellID] == nil then
                    self.Spells[spellID] = {};
                end

                tinsert(self.Spells[spellID], button);

                if keyBind then
                    FetchKeybind(self, spellID, i)
                end
            end
        end
    end
    
    function ConRO:Fetch_nUI()
        for i = 1, 12 do
            local button = _G['nUI_ActionBar_Button' .. i];
            if not button then
                break;
            end
            FetchSpells(self, button,i, true)
        end
        for i = 1, 12 do
            local button = _G['nUI_TopLeftBar_Button' .. i];
            if not button then
                break;
            end
            FetchSpells(self, button,i, true)
        end
        for i = 1, 12 do
            local button = _G['nUI_TopRightBar_Button' .. i];
            if not button then
                break;
            end
            FetchSpells(self, button,i, true)
        end
    end

    function ConRO:FetchDef_nUI()
        for i = 1, 12 do
            local button = _G['nUI_ActionBar_Button' .. i];
            if not button then
                break;
            end            
            FetchSpells(self, button, i)
        end
        for i = 1, 12 do
            local button = _G['nUI_TopLeftBar_Button' .. i];
            if not button then
                break;
            end
            FetchSpells(self, button,i)
        end
        for i = 1, 12 do
            local button = _G['nUI_TopRightBar_Button' .. i];
            if not button then
                break;
            end
            FetchSpells(self, button,i, true)
        end
    end
    
    hooksecurefunc(ConRO, "Fetch", function() ConRO:Fetch_nUI() end );
    hooksecurefunc(ConRO, "FetchDef", function() ConRO:FetchDef_nUI() end);
        
end


-------------------------------------------------------------------------------------
-- Events
local addonLoaded = false
local conROLoaded = false

local function onEvent( self, event, arg1 )
    if event == "ADDON_LOADED" then
        if arg1 == addonName then addonLoaded = true end
        if arg1 == "ConRO" then conROLoaded = true end
        if addonLoaded then
            conROLoaded = IsAddOnLoaded("ConRO") 
            self:RegisterEvent( "PLAYER_ENTERING_WORLD" );
        end

    elseif event == "PLAYER_ENTERING_WORLD" then
        if conROLoaded then
            conRO = LibStub("AceAddon-3.0"):GetAddon("ConRO");
            if conRO then
                DetectConRO()
            end	
        end
    end
end

-------------------------------------------------------------------------------------
-- Events Frame

local frame = CreateFrame( "Frame", "nUI_RotationHelperEvents", WorldFrame )
frame:SetScript( "OnEvent", onEvent );
frame:RegisterEvent( "ADDON_LOADED" );
